===============================
xmastree
===============================

.. image:: https://badge.fury.io/py/xmastree.png
    :target: http://badge.fury.io/py/xmastree

.. image:: https://travis-ci.org/axiaoxin/xmastree.png?branch=master
        :target: https://travis-ci.org/axiaoxin/xmastree

.. image:: https://pypip.in/d/xmastree/badge.png
        :target: https://pypi.python.org/pypi/xmastree


merry xmas


    In [1]: import xmastree
    In [2]: xmastree.XmasTree().show()
                                       *
                                      / \
                                      / \
                                     /   \
                                     /  @\
                                    /  @  \
                                    / !  $\
                                   /      ^\
                                   /#   !  \
                                  /^        \
                                  /         \
                                 /!  #     $ \
                                 /         $ \
                                /^            \
                                /         % ! \
                               /&@# ^@      !  \
                               /    #          \
                              /@  &  $ #%       \
                             /___________________\
                                      | |
                                      

* Free software: BSD license
* Documentation: https://xmastree.readthedocs.org.

Features
--------

* TODO
